pub fn generate_rust(policy: &RbacPolicy) -> StringExpand description
Generate Rust source code for the roles defined in policy.
The output is a complete .rs file ready to be include!’d or written to disk.
pub fn generate_rust(policy: &RbacPolicy) -> StringGenerate Rust source code for the roles defined in policy.
The output is a complete .rs file ready to be include!’d or written to disk.